==> libunibreak-4.0.tar.gz: libunibreak-4.0/doc/html/search/all_f.js <==
var searchData=
[
  ['wb_5fprop_5fdefault',['wb_prop_default',['../wordbreakdata_8c.html#a6141e6bf0cb2beaea11203d7fcbed63a',1,'wordbreakdata.c']]],
  ['wbp_5faletter',['WBP_ALetter',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a24852694e43fdf9e026674b6a43e8e8f',1,'wordbreakdef.h']]],
  ['wbp_5fany',['WBP_Any',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40abe713ea1e84dc892c037c7d53c069d25',1,'wordbreakdef.h']]],
  ['wbp_5fcr',['WBP_CR',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40aeae4a2e3a66a6da1921c5c5a22b5343d',1,'wordbreakdef.h']]],
  ['wbp_5fdouble_5fquote',['WBP_Double_Quote',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40af8fcf72888bae0eab2d87586b78f9144',1,'wordbreakdef.h']]],
  ['wbp_5fe_5fbase',['WBP_E_Base',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40aa24b1ad4fe9c2e9c3b8a89f7ea281ede',1,'wordbreakdef.h']]],
  ['wbp_5fe_5fbase_5fgaz',['WBP_E_Base_GAZ',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a6956054ec2783a083f6d849d8c27d861',1,'wordbreakdef.h']]],
  ['wbp_5fe_5fmodifier',['WBP_E_Modifier',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40ac674e0bad4d7cbe8ff064e5eb33ad273',1,'wordbreakdef.h']]],
  ['wbp_5fextend',['WBP_Extend',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a0b76a80045ee004df3ea8bfe9c60c929',1,'wordbreakdef.h']]],
  ['wbp_5fextendnumlet',['WBP_ExtendNumLet',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a9a9766370b8f5cdfc5c55cadd64f8821',1,'wordbreakdef.h']]],
  ['wbp_5fformat',['WBP_Format',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40ab1e680527a42bfff9243d5f748f01fd4',1,'wordbreakdef.h']]],
  ['wbp_5fglue_5fafter_5fzwj',['WBP_Glue_After_Zwj',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a01f7dc945ae21fdc7ad2a2cf65d1c3e2',1,'wordbreakdef.h']]],
  ['wbp_5fhebrew_5fletter',['WBP_Hebrew_Letter',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a55666e5976f31f980519469dd6a3d32e',1,'wordbreakdef.h']]],
  ['wbp_5fkatakana',['WBP_Katakana',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a145359c5c379f4f179aea5b1b26b0c69',1,'wordbreakdef.h']]],
  ['wbp_5flf',['WBP_LF',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40af1c571a6c22efdb0fce90fbb5edbd924',1,'wordbreakdef.h']]],
  ['wbp_5fmidletter',['WBP_MidLetter',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a91ed7c0bf56a72563331c7fc382e8739',1,'wordbreakdef.h']]],
  ['wbp_5fmidnum',['WBP_MidNum',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a431e6bb4d6bcbb68ab6bfce7a47bb581',1,'wordbreakdef.h']]],
  ['wbp_5fmidnumlet',['WBP_MidNumLet',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a911be1fcd593b1d0823f4e2f746340ce',1,'wordbreakdef.h']]],
  ['wbp_5fnewline',['WBP_Newline',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a798e8c979eb3fe0fc6f314c49b588f83',1,'wordbreakdef.h']]],
  ['wbp_5fnumeric',['WBP_Numeric',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a93c0d1702bfb95fdacf20769c0169fd2',1,'wordbreakdef.h']]],
  ['wbp_5fregional_5findicator',['WBP_Regional_Indicator',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40afbbadd38b3920c0e4a705a5115cd5658',1,'wordbreakdef.h']]],
  ['wbp_5fsingle_5fquote',['WBP_Single_Quote',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40aa3c804e176682c917d2968bf96a829ad',1,'wordbreakdef.h']]],
  ['wbp_5fundefined',['WBP_Undefined',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a8fa8b8896a8499f03904a14d18cf52bf',1,'wordbreakdef.h']]],
  ['wbp_5fzwj',['WBP_ZWJ',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a0fec8f32bdf476b72ecbff2639166663',1,'wordbreakdef.h']]],
  ['wordbreak_2ec',['wordbreak.c',['../wordbreak_8c.html',1,'']]],
  ['wordbreak_2eh',['wordbreak.h',['../wordbreak_8h.html',1,'']]],
  ['wordbreak_5fbreak',['WORDBREAK_BREAK',['../wordbreak_8h.html#a332d8bcb62ffba480853bd0198caf5b2',1,'wordbreak.h']]],
  ['wordbreak_5finsideachar',['WORDBREAK_INSIDEACHAR',['../wordbreak_8h.html#a889a6cdfbdd611a8ee35248b870899be',1,'wordbreak.h']]],
  ['wordbreak_5fnobreak',['WORDBREAK_NOBREAK',['../wordbreak_8h.html#a62204b16a75ec9d5d8272cf29d7f587a',1,'wordbreak.h']]],
  ['wordbreakclass',['WordBreakClass',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40',1,'wordbreakdef.h']]],
  ['wordbreakdata_2ec',['wordbreakdata.c',['../wordbreakdata_8c.html',1,'']]],
  ['wordbreakdef_2eh',['wordbreakdef.h',['../wordbreakdef_8h.html',1,'']]],
  ['wordbreakproperties',['WordBreakProperties',['../structWordBreakProperties.html',1,'']]]
];

==> libunibreak-4.1.tar.gz: libunibreak-4.1/doc/html/search/all_f.js <==
var searchData=
[
  ['wb_5fprop_5fdefault',['wb_prop_default',['../wordbreakdata_8c.html#a6141e6bf0cb2beaea11203d7fcbed63a',1,'wordbreakdata.c']]],
  ['wbp_5faletter',['WBP_ALetter',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a24852694e43fdf9e026674b6a43e8e8f',1,'wordbreakdef.h']]],
  ['wbp_5fany',['WBP_Any',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40abe713ea1e84dc892c037c7d53c069d25',1,'wordbreakdef.h']]],
  ['wbp_5fcr',['WBP_CR',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40aeae4a2e3a66a6da1921c5c5a22b5343d',1,'wordbreakdef.h']]],
  ['wbp_5fdouble_5fquote',['WBP_Double_Quote',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40af8fcf72888bae0eab2d87586b78f9144',1,'wordbreakdef.h']]],
  ['wbp_5fextend',['WBP_Extend',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a0b76a80045ee004df3ea8bfe9c60c929',1,'wordbreakdef.h']]],
  ['wbp_5fextendnumlet',['WBP_ExtendNumLet',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a9a9766370b8f5cdfc5c55cadd64f8821',1,'wordbreakdef.h']]],
  ['wbp_5fformat',['WBP_Format',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40ab1e680527a42bfff9243d5f748f01fd4',1,'wordbreakdef.h']]],
  ['wbp_5fhebrew_5fletter',['WBP_Hebrew_Letter',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a55666e5976f31f980519469dd6a3d32e',1,'wordbreakdef.h']]],
  ['wbp_5fkatakana',['WBP_Katakana',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a145359c5c379f4f179aea5b1b26b0c69',1,'wordbreakdef.h']]],
  ['wbp_5flf',['WBP_LF',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40af1c571a6c22efdb0fce90fbb5edbd924',1,'wordbreakdef.h']]],
  ['wbp_5fmidletter',['WBP_MidLetter',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a91ed7c0bf56a72563331c7fc382e8739',1,'wordbreakdef.h']]],
  ['wbp_5fmidnum',['WBP_MidNum',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a431e6bb4d6bcbb68ab6bfce7a47bb581',1,'wordbreakdef.h']]],
  ['wbp_5fmidnumlet',['WBP_MidNumLet',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a911be1fcd593b1d0823f4e2f746340ce',1,'wordbreakdef.h']]],
  ['wbp_5fnewline',['WBP_Newline',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a798e8c979eb3fe0fc6f314c49b588f83',1,'wordbreakdef.h']]],
  ['wbp_5fnumeric',['WBP_Numeric',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a93c0d1702bfb95fdacf20769c0169fd2',1,'wordbreakdef.h']]],
  ['wbp_5fregional_5findicator',['WBP_Regional_Indicator',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40afbbadd38b3920c0e4a705a5115cd5658',1,'wordbreakdef.h']]],
  ['wbp_5fsingle_5fquote',['WBP_Single_Quote',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40aa3c804e176682c917d2968bf96a829ad',1,'wordbreakdef.h']]],
  ['wbp_5fundefined',['WBP_Undefined',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a8fa8b8896a8499f03904a14d18cf52bf',1,'wordbreakdef.h']]],
  ['wbp_5fwsegspace',['WBP_WSegSpace',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a8ecd9a46f5ebb00a36831c6495bb5e0d',1,'wordbreakdef.h']]],
  ['wbp_5fzwj',['WBP_ZWJ',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40a0fec8f32bdf476b72ecbff2639166663',1,'wordbreakdef.h']]],
  ['wordbreak_2ec',['wordbreak.c',['../wordbreak_8c.html',1,'']]],
  ['wordbreak_2eh',['wordbreak.h',['../wordbreak_8h.html',1,'']]],
  ['wordbreak_5fbreak',['WORDBREAK_BREAK',['../wordbreak_8h.html#a332d8bcb62ffba480853bd0198caf5b2',1,'wordbreak.h']]],
  ['wordbreak_5finsideachar',['WORDBREAK_INSIDEACHAR',['../wordbreak_8h.html#a889a6cdfbdd611a8ee35248b870899be',1,'wordbreak.h']]],
  ['wordbreak_5fnobreak',['WORDBREAK_NOBREAK',['../wordbreak_8h.html#a62204b16a75ec9d5d8272cf29d7f587a',1,'wordbreak.h']]],
  ['wordbreakclass',['WordBreakClass',['../wordbreakdef_8h.html#a6c4866a2394c55d8a3b04a21a1cd5d40',1,'wordbreakdef.h']]],
  ['wordbreakdata_2ec',['wordbreakdata.c',['../wordbreakdata_8c.html',1,'']]],
  ['wordbreakdef_2eh',['wordbreakdef.h',['../wordbreakdef_8h.html',1,'']]],
  ['wordbreakproperties',['WordBreakProperties',['../structWordBreakProperties.html',1,'']]]
];
